import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

import unittest
import CPSSkinsTestCase
from Testing import ZopeTestCase

HTTP_OK = 200
HTTP_UNAUTHORIZED = 401
HTTP_REDIRECT = 302

class TestFunctional(ZopeTestCase.Functional, CPSSkinsTestCase.CPSSkinsTestCase):
    def afterSetUp(self):
        tmtool = self.portal.portal_themes
        if 'PortalTheme' in tmtool.objectIds():
           tmtool.manage_delObjects(['PortalTheme'])
        self.theme_container = tmtool.addPortalTheme(empty=1)
        self.basic_auth = '%s:secret' % self.login_id
        self.theme_url = self.theme_container.absolute_url(1)


# Testing as 'Manager'
class TestFunctionalAsManager(TestFunctional):
    login_id = 'cpsskins_root'

    def test_edit_modes(self):
        for mode in ['layout', 'mixed', 'wysiwyg']:
            test_url = '/%s/edit_form?edit_mode=%s' % (self.theme_url, mode)
            response = self.publish(test_url, self.basic_auth)
            self.assertEqual(response.getStatus(), HTTP_OK)

    def test_edit_styles(self):
        test_url = '/%s/cpsskins_edit_styles' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_edit_images(self):
        test_url = '/%s/cpsskins_edit_images' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_edit_palettes(self):
        test_url = '/%s/cpsskins_edit_palettes' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_cache_manager(self):
        test_url = '/%s/cpsskins_cache_manager' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_ZMI(self):
        test_url = '/%s/manage_main' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_move_Templet_inside_same_PageBlock(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        pageblock.maxcols = int(2)
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        templet.xpos = int(1)
        templet_id = pageblock.objectValues('Text Box Templet')[0].getId()
        test_url = '/%s/cpsskins_move_templet?xpos=%s&ypos=%s&dest_pageblock=%s' \
           % (templet.absolute_url(1), 0, 0, pageblock.getId())
        response = self.publish(test_url, self.basic_auth)
        templet_moved_id = pageblock.objectValues('Text Box Templet')[0].getId()
        self.assert_(response.getStatus() != HTTP_UNAUTHORIZED)
        self.assert_(templet_id == templet_moved_id)

    def test_move_Templet_between_different_PageBlocks(self):
        theme_container = self.theme_container
        pageblock_src = theme_container.addPageBlock()
        pageblock_dest = theme_container.addPageBlock()
        pageblock_dest.maxcols = int(2)
        templet = pageblock_src.addTemplet(type_name='Text Box Templet')
        templet.xpos = int(0)
        templet_id = pageblock_src.objectValues('Text Box Templet')[0].getId()
        test_url = '/%s/cpsskins_move_templet?xpos=%s&ypos=%s&dest_pageblock=%s' \
           % (templet.absolute_url(1), 1, 0, pageblock_dest.getId())
        response = self.publish(test_url, self.basic_auth)
        templet_moved_id = pageblock_dest.objectValues('Text Box Templet')[0].getId()
        self.assert_(response.getStatus() != HTTP_UNAUTHORIZED)
        self.assert_(templet_id == templet_moved_id)

    def test_addTemplet(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        pageblock.maxcols = 2
        test_url = '/%s/cpsskins_templet_add?xpos=%s&ypos=%s&type_name=%s' \
            % (pageblock.absolute_url(1), 1, 0, 'Text Box Templet')
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() != HTTP_UNAUTHORIZED)
        templet = pageblock.objectValues('Text Box Templet')[0]
        self.assert_(templet.xpos == 1)

    def test_copy_Templet_to_another_Theme(self):
        theme_container = self.theme_container
        tmtool = self.portal.portal_themes
        dest_theme_container = tmtool.addPortalTheme(empty=1)
        pageblock_src = theme_container.addPageBlock()
        pageblock_dest = dest_theme_container.addPageBlock()
        pageblock_dest.maxcols = int(2)
        templet = pageblock_src.addTemplet(type_name='Text Box Templet')
        templet.xpos = int(0)
        templet_id = templet.getId()
        test_url = '/%s/cpsskins_move_templet?xpos=%s&ypos=%s&dest_pageblock=%s&dest_theme=%s' \
           % (templet.absolute_url(1), 1, 0, pageblock_dest.getId(), dest_theme_container.getId())
        response = self.publish(test_url, self.basic_auth)
        templet_copied = pageblock_dest.objectValues('Text Box Templet')[0]
        self.assert_(response.getStatus() != HTTP_UNAUTHORIZED)
        self.assert_(getattr(templet_copied, 'title'), getattr(templet, 'title'))
        self.assert_(getattr(templet_copied, 'align'), getattr(templet, 'align'))
        self.assert_(getattr(templet_copied, 'text'), getattr(templet, 'text'))
        self.assert_(getattr(templet_copied, 'text_format'), getattr(templet, 'text_format'))

    def test_addPageBlock_at_the_top(self):
        theme_container = self.theme_container
        orig_pageblock = theme_container.addPageBlock()
        test_url = '/%s/cpsskins_pageblock_add?pageblock_ypos=%s' \
            % (theme_container.absolute_url(1), 0)
        response = self.publish(test_url, self.basic_auth)
        pageblocks = theme_container.objectValues('Page Block')
        self.assert_(response.getStatus() != HTTP_UNAUTHORIZED)
        self.assert_(len(pageblocks) == 2)
        self.assert_(pageblocks[1].getId() == orig_pageblock.getId())

    def test_addPageBlock_at_the_bottom(self):
        theme_container = self.theme_container
        orig_pageblock = theme_container.addPageBlock()
        test_url = '/%s/cpsskins_pageblock_add' % theme_container.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        pageblocks = theme_container.objectValues('Page Block')
        self.assert_(response.getStatus() != HTTP_UNAUTHORIZED)
        self.assert_(len(pageblocks) == 2)
        self.assert_(pageblocks[0].getId() == orig_pageblock.getId())


    def test_Templet_toggle(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        templet.closed = 0
        test_url = '/%s/cpsskins_object_toggle' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() !=  HTTP_UNAUTHORIZED )
        self.assert_(not templet.closed)
        templet.closed = 1
        test_url = '/%s/cpsskins_object_toggle' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() !=  HTTP_UNAUTHORIZED )
        self.assert_(templet.closed)


# Testing as 'Member'
class TestFunctionalAsMember(TestFunctional):
    login_id = 'cpsskins_user'

    def test_edit_modes(self):
        for mode in ['layout', 'mixed', 'wysiwyg']:
            test_url = '/%s/edit_form?edit_mode=%s' % (self.theme_url, mode)
            response = self.publish(test_url, self.basic_auth)
            self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_edit_styles(self):
        test_url = '/%s/cpsskins_edit_styles' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_edit_images(self):
        test_url = '/%s/cpsskins_edit_images' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_edit_palettes(self):
        test_url = '/%s/cpsskins_edit_palettes' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_cache_manager(self):
        test_url = '/%s/cpsskins_cache_manager' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_ZMI(self):
        test_url = '/%s/manage_main' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_move_Templet_inside_same_PageBlock(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        pageblock.maxcols = int(2)
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        templet.xpos = int(1)
        templet_id = pageblock.objectValues('Text Box Templet')[0].getId()
        test_url = '/%s/cpsskins_move_templet?xpos=%s&ypos=%s&dest_pageblock=%s' \
           % (templet.absolute_url(1), 0, 0, pageblock.getId())
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() == HTTP_UNAUTHORIZED)

    def test_move_Templet_between_different_PageBlocks(self):
        theme_container = self.theme_container
        pageblock_src = theme_container.addPageBlock()
        pageblock_dest = theme_container.addPageBlock()
        pageblock_dest.maxcols = int(2)
        templet = pageblock_src.addTemplet(type_name='Text Box Templet')
        templet.xpos = int(0)
        test_url = '/%s/cpsskins_move_templet?xpos=%s&ypos=%s&dest_pageblock=%s' \
           % (templet.absolute_url(1), 1, 0, pageblock_dest.getId())
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() == HTTP_UNAUTHORIZED)

    def test_addTemplet(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        pageblock.maxcols = 2
        test_url = '/%s/cpsskins_templet_add?xpos=%s&ypos=%s&type_name=%s' \
            % (pageblock.absolute_url(1), 1, 0, 'Text Box Templet')
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() == HTTP_UNAUTHORIZED)

    def test_copy_Templet_to_another_Theme(self):
        theme_container = self.theme_container
        tmtool = self.portal.portal_themes
        dest_theme_container = tmtool.addPortalTheme(empty=1)
        pageblock_src = theme_container.addPageBlock()
        pageblock_dest = dest_theme_container.addPageBlock()
        pageblock_dest.maxcols = int(2)
        templet = pageblock_src.addTemplet(type_name='Text Box Templet')
        templet.xpos = int(0)
        templet_id = templet.getId()
        test_url = '/%s/cpsskins_move_templet?xpos=%s&ypos=%s&dest_pageblock=%s&dest_theme=%s' \
           % (templet.absolute_url(1), 1, 0, pageblock_dest.getId(), dest_theme_container.getId())
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() == HTTP_UNAUTHORIZED)

    def test_addPageBlock_at_the_top(self):                    
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        test_url = '/%s/cpsskins_pageblock_add?pageblock_ypos=%s' \
            % (theme_container.absolute_url(1), 0)
        response = self.publish(test_url, self.basic_auth)
        pageblocks = theme_container.objectValues('Page Block')
        self.assert_(response.getStatus() == HTTP_UNAUTHORIZED)
             
    def test_addPageBlock_at_the_bottom(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        test_url = '/%s/cpsskins_pageblock_add' % theme_container.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        pageblocks = theme_container.objectValues('Page Block')
        self.assert_(response.getStatus() == HTTP_UNAUTHORIZED)

    def test_Templet_toggle(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        templet.closed = 0
        test_url = '/%s/cpsskins_object_toggle' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() ==  HTTP_UNAUTHORIZED )
        self.assert_(not templet.closed)

    def test_Calendar_browse(self):
        if 'portal_calendar' in self.portal.objectIds():
            theme_container = self.theme_container
            pageblock = theme_container.addPageBlock()
            templet = pageblock.addTemplet(type_name='Calendar Templet')
            portal = self.portal
            test_url = '%s/cpsskins_calendar_browse?dir=nextmonth' % portal.absolute_url(1)
            response = self.publish(test_url, self.basic_auth)
            self.assertEqual(response.getStatus(), HTTP_REDIRECT)
            test_url = '%s/cpsskins_calendar_browse?dir=prevmonth' % portal.absolute_url(1)
            response = self.publish(test_url, self.basic_auth)
            self.assertEqual(response.getStatus(), HTTP_REDIRECT)
            test_url = '%s/cpsskins_calendar_browse?dir=nextmonth&month:int=9&year:int=2004' % portal.absolute_url(1)
            response = self.publish(test_url, self.basic_auth)
            self.assertEqual(response.getStatus(), HTTP_REDIRECT)
            test_url = '%s/cpsskins_calendar_browse?dir=prevmonth&month:int=9&year:int=2004' % portal.absolute_url(1)
            response = self.publish(test_url, self.basic_auth)
            self.assertEqual(response.getStatus(), HTTP_REDIRECT)

# Testing as 'Theme Manager'
class TestFunctionalAsThemeManager(TestFunctional):
    login_id = 'cpsskins_theme_manager'

    def test_edit_modes(self):
        for mode in ['layout', 'mixed', 'wysiwyg']:
            test_url = '/%s/edit_form?edit_mode=%s' % (self.theme_url, mode)
            response = self.publish(test_url, self.basic_auth)
            self.assertEqual(response.getStatus(), HTTP_OK)

    def test_edit_styles(self):
        test_url = '/%s/cpsskins_edit_styles' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_edit_images(self):
        test_url = '/%s/cpsskins_edit_images' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_edit_palettes(self):
        test_url = '/%s/cpsskins_edit_palettes' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_OK)

    def test_cache_manager(self):
        test_url = '/%s/cpsskins_cache_manager' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_ZMI(self):
        test_url = '/%s/manage_main' % self.theme_url
        response = self.publish(test_url, self.basic_auth)
        self.assertEqual(response.getStatus(), HTTP_UNAUTHORIZED)

    def test_move_Templet_inside_same_PageBlock(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        pageblock.maxcols = int(2)
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        templet.xpos = int(1)
        templet_id = pageblock.objectValues('Text Box Templet')[0].getId()
        test_url = '/%s/cpsskins_move_templet?xpos=%s&ypos=%s&dest_pageblock=%s' \
           % (templet.absolute_url(1), 0, 0, pageblock.getId())
        response = self.publish(test_url, self.basic_auth)
        templet_moved_id = pageblock.objectValues('Text Box Templet')[0].getId()
        self.assert_(response.getStatus() != HTTP_UNAUTHORIZED)
        self.assert_(templet_id == templet_moved_id)

    def test_move_Templet_between_different_PageBlocks(self):
        theme_container = self.theme_container
        pageblock_src = theme_container.addPageBlock()
        pageblock_dest = theme_container.addPageBlock()
        pageblock_dest.maxcols = int(2)
        templet = pageblock_src.addTemplet(type_name='Text Box Templet')
        templet.xpos = int(0)
        templet_id = pageblock_src.objectValues('Text Box Templet')[0].getId()
        test_url = '/%s/cpsskins_move_templet?xpos=%s&ypos=%s&dest_pageblock=%s' \
           % (templet.absolute_url(1), 1, 0, pageblock_dest.getId())
        response = self.publish(test_url, self.basic_auth)
        templet_moved_id = pageblock_dest.objectValues('Text Box Templet')[0].getId()
        self.assert_(response.getStatus() != HTTP_UNAUTHORIZED)
        self.assert_(templet_id == templet_moved_id)


    def test_addTemplet(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        pageblock.maxcols = 2
        test_url = '/%s/cpsskins_templet_add?xpos=%s&ypos=%s&type_name=%s' \
            % (pageblock.absolute_url(1), 1, 0, 'Text Box Templet')
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() != HTTP_UNAUTHORIZED)
        templet = pageblock.objectValues('Text Box Templet')[0]
        self.assert_(templet.xpos == 1)



    def test_copy_Templet_to_another_Theme(self):
        theme_container = self.theme_container
        tmtool = self.portal.portal_themes
        dest_theme_container = tmtool.addPortalTheme(empty=1)
        pageblock_src = theme_container.addPageBlock()
        pageblock_dest = dest_theme_container.addPageBlock()
        pageblock_dest.maxcols = int(2)
        templet = pageblock_src.addTemplet(type_name='Text Box Templet')
        templet.xpos = int(0)
        templet_id = templet.getId()
        test_url = '/%s/cpsskins_move_templet?xpos=%s&ypos=%s&dest_pageblock=%s&dest_theme=%s' \
           % (templet.absolute_url(1), 1, 0, pageblock_dest.getId(), dest_theme_container.getId())
        response = self.publish(test_url, self.basic_auth)
        templet_copied = pageblock_dest.objectValues('Text Box Templet')[0]
        self.assert_(response.getStatus() != HTTP_UNAUTHORIZED)
        self.assert_(getattr(templet_copied, 'title'), getattr(templet, 'title'))
        self.assert_(getattr(templet_copied, 'align'), getattr(templet, 'align'))
        self.assert_(getattr(templet_copied, 'text'), getattr(templet, 'text'))
        self.assert_(getattr(templet_copied, 'text_format'), getattr(templet, 'text_format'))

    def test_addPageBlock_at_the_top(self):                    
        theme_container = self.theme_container
        orig_pageblock = theme_container.addPageBlock()
        test_url = '/%s/cpsskins_pageblock_add?pageblock_ypos=%s' \
            % (theme_container.absolute_url(1), 0)
        response = self.publish(test_url, self.basic_auth)
        pageblocks = theme_container.objectValues('Page Block')
        self.assert_(response.getStatus() != HTTP_UNAUTHORIZED)
        self.assert_(len(pageblocks) == 2)
        self.assert_(pageblocks[1].getId() == orig_pageblock.getId())
             
    def test_addPageBlock_at_the_bottom(self):
        theme_container = self.theme_container
        orig_pageblock = theme_container.addPageBlock()
        test_url = '/%s/cpsskins_pageblock_add' % theme_container.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        pageblocks = theme_container.objectValues('Page Block')
        self.assert_(response.getStatus() != HTTP_UNAUTHORIZED)
        self.assert_(len(pageblocks) == 2)
        self.assert_(pageblocks[0].getId() == orig_pageblock.getId())

    def test_Templet_toggle(self):
        theme_container = self.theme_container
        pageblock = theme_container.addPageBlock()
        templet = pageblock.addTemplet(type_name='Text Box Templet')
        templet.closed = 0
        test_url = '/%s/cpsskins_object_toggle' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() !=  HTTP_UNAUTHORIZED )
        self.assert_(not templet.closed)
        templet.closed = 1
        test_url = '/%s/cpsskins_object_toggle' % templet.absolute_url(1)
        response = self.publish(test_url, self.basic_auth)
        self.assert_(response.getStatus() !=  HTTP_UNAUTHORIZED )
        self.assert_(templet.closed)


def test_suite():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(TestFunctionalAsManager))
    suite.addTest(unittest.makeSuite(TestFunctionalAsMember))
    suite.addTest(unittest.makeSuite(TestFunctionalAsThemeManager))
    return suite

if __name__ == '__main__':
    framework(descriptions=1, verbosity=2)

